package net.knarcraft.ffmpegconverter.streams;

/**
 * This class represents a ffmpeg audio stream
 */
public class AudioStream extends AbstractStream implements StreamObject {

    private final int channels;
    private final String title;

    /**
     * Instantiates a new audio stream
     *
     * @param codecName     <p>The codec of the audio stream.</p>
     * @param absoluteIndex <p>The index of the audio stream.</p>
     * @param relativeIndex <p>The index of the audio stream relative to other audio streams.</p>
     * @param language      <p>The language of the audio stream.</p>
     * @param title         <p>The title of the audio stream.</p>
     * @param channels      <p>The number of channels for the audio stream.</p>
     */
    public AudioStream(String codecName, int absoluteIndex, int relativeIndex, String language, String title,
                       int channels) {
        this.codecName = codecName;
        this.absoluteIndex = absoluteIndex;
        this.language = language;
        this.title = title;
        this.relativeIndex = relativeIndex;
        this.channels = channels;
    }

    /**
     * Gets the number of channels for the audio stream
     *
     * @return <p>The number of channels for the audio stream.</p>
     */
    public int getChannels() {
        return this.channels;
    }

    /**
     * Gets the title of the audio stream
     * <p>
     * TODO: While this isn't useful right now, it would be useful if the software allowed first looking at available
     *  steams, and then choose the correct stream based on the name
     *
     * @return <p>The title of the audio stream.</p>
     */
    public String getTitle() {
        return this.title;
    }

}
